==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/lottery/DrawLotteryVO.java <==
package com.thebeastshop.support.vo.lottery;

import java.util.List;

/**
 * 抽奖结果详情
 * Created by feilong.gao on 2016/12/6.
 */
public class DrawLotteryVO {

    /**
     * 是否能抽奖
     */
    private Boolean canDraw;

    /**
     * 中奖
     */
    private Boolean win;

    /**
     * 失败原因
     */
    private String failReason;

    /**
     * 中奖详情
     */
    private LotteryRecordVO lotteryRecord;

    /**
     * 抽奖记录
     */
    private List<LotteryRecordVO> lotteryRecords;

    /**
     * 消耗积分
     */
    private Integer consumePoint;

    /**
     * 会员积分
     */
    private Integer points;

    public Boolean getCanDraw() {
        return canDraw;
    }

    public void setCanDraw(Boolean canDraw) {
        this.canDraw = canDraw;
    }

    public Boolean getWin() {
        return win;
    }

    public void setWin(Boolean win) {
        this.win = win;
    }

    public String getFailReason() {
        return failReason;
    }

    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    public LotteryRecordVO getLotteryRecord() {
        return lotteryRecord;
    }

    public void setLotteryRecord(LotteryRecordVO lotteryRecord) {
        this.lotteryRecord = lotteryRecord;
    }

    public List<LotteryRecordVO> getLotteryRecords() {
        return lotteryRecords;
    }

    public void setLotteryRecords(List<LotteryRecordVO> lotteryRecords) {
        this.lotteryRecords = lotteryRecords;
    }

    public Integer getConsumePoint() {
        return consumePoint;
    }

    public void setConsumePoint(Integer consumePoint) {
        this.consumePoint = consumePoint;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    @Override
    public String toString() {
        final StringBuffer sb = new StringBuffer("DrawLotteryVO{");
        sb.append("canDraw=").append(canDraw);
        sb.append(", win=").append(win);
        sb.append(", failReason='").append(failReason).append('\'');
        sb.append(", lotteryRecord=").append(lotteryRecord);
        sb.append(", lotteryRecords=").append(lotteryRecords);
        sb.append(", consumePoint=").append(consumePoint);
        sb.append(", points=").append(points);
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-2.6.13-sources.jar: com/thebeastshop/support/vo/lottery/DrawLotteryVO.java <==
package com.thebeastshop.support.vo.lottery;

import java.util.List;

/**
 * 抽奖结果详情
 * Created by feilong.gao on 2016/12/6.
 */
public class DrawLotteryVO {

    /**
     * 是否能抽奖
     */
    private Boolean canDraw;

    /**
     * 中奖
     */
    private Boolean win;

    /**
     * 失败原因
     */
    private String failReason;

    /**
     * 中奖详情
     */
    private LotteryRecordVO lotteryRecord;


    /**
     * 未中奖详情
     */
    private NoPrizeVO noPrize;

    /**
     * 抽奖记录
     */
    private List<LotteryRecordVO> lotteryRecords;

    /**
     * 消耗积分
     */
    private Integer consumePoint;

    /**
     * 会员积分
     */
    private Integer points;

    public Boolean getCanDraw() {
        return canDraw;
    }

    public void setCanDraw(Boolean canDraw) {
        this.canDraw = canDraw;
    }

    public Boolean getWin() {
        return win;
    }

    public void setWin(Boolean win) {
        this.win = win;
    }

    public String getFailReason() {
        return failReason;
    }

    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    public LotteryRecordVO getLotteryRecord() {
        return lotteryRecord;
    }

    public void setLotteryRecord(LotteryRecordVO lotteryRecord) {
        this.lotteryRecord = lotteryRecord;
    }

    public List<LotteryRecordVO> getLotteryRecords() {
        return lotteryRecords;
    }

    public void setLotteryRecords(List<LotteryRecordVO> lotteryRecords) {
        this.lotteryRecords = lotteryRecords;
    }

    public Integer getConsumePoint() {
        return consumePoint;
    }

    public void setConsumePoint(Integer consumePoint) {
        this.consumePoint = consumePoint;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public NoPrizeVO getNoPrize() {
        return noPrize;
    }

    public void setNoPrize(NoPrizeVO noPrize) {
        this.noPrize = noPrize;
    }

    @Override
    public String toString() {
        return "DrawLotteryVO{" +
                "canDraw=" + canDraw +
                ", win=" + win +
                ", failReason='" + failReason + '\'' +
                ", lotteryRecord=" + lotteryRecord +
                ", noPrize=" + noPrize +
                ", lotteryRecords=" + lotteryRecords +
                ", consumePoint=" + consumePoint +
                ", points=" + points +
                '}';
    }
}
